@@ -1,6 +1,6 @@
 /*
  *  Phusion Passenger - https://www.phusionpassenger.com/
- *  Copyright (c) 2010-2016 Phusion Holding B.V.
+ *  Copyright (c) 2010-2017 Phusion Holding B.V.
  *
  *  "Passenger", "Phusion Passenger" and "Union Station" are registered
  *  trademarks of Phusion Holding B.V.
@@ -104,7 +104,8 @@ void        psg_watchdog_launcher_free(PsgWatchdogLauncher *launcher);
 #include <MessageClient.h>
 #include <Exceptions.h>
 #include <ResourceLocator.h>
-#include <Logging.h>
+#include <LoggingKit/LoggingKit.h>
+#include <LoggingKit/Context.h>
 #include <Utils.h>
 #include <Utils/IOUtils.h>
 #include <Utils/MessageIO.h>
@@ -197,8 +198,8 @@ private:
 	 * then it will set `pid` to -1.
 	 */
 	void inspectWatchdogCrashReason(pid_t &pid) {
-		this_thread::disable_interruption di;
-		this_thread::disable_syscall_interruption dsi;
+		boost::this_thread::disable_interruption di;
+		boost::this_thread::disable_syscall_interruption dsi;
 		int ret, status;
 
 		/* Upon noticing that something went wrong, the watchdog
@@ -268,7 +269,7 @@ private:
 
 	static void killProcessGroupAndWait(pid_t *pid, unsigned long long timeout = 0) {
 		if (*pid != -1 && (timeout == 0 || timedWaitPid(*pid, NULL, timeout) <= 0)) {
-			this_thread::disable_syscall_interruption dsi;
+			boost::this_thread::disable_syscall_interruption dsi;
 			syscalls::killpg(*pid, SIGKILL);
 			syscalls::waitpid(*pid, NULL, 0);
 			*pid = -1;
@@ -306,7 +307,7 @@ public:
 
 	~WatchdogLauncher() {
 		if (mPid != 0) {
-			this_thread::disable_syscall_interruption dsi;
+			boost::this_thread::disable_syscall_interruption dsi;
 
 			/* Send a message down the feedback fd to tell the watchdog
 			 * that we're shutting down cleanly. Closing the fd without
@@ -344,8 +345,8 @@ public:
 		const boost::function<void ()> &afterFork = boost::function<void ()>())
 	{
 		TRACE_POINT();
-		this_thread::disable_interruption di;
-		this_thread::disable_syscall_interruption dsi;
+		boost::this_thread::disable_interruption di;
+		boost::this_thread::disable_syscall_interruption dsi;
 		ResourceLocator locator(passengerRoot);
 
 		string agentFilename;
@@ -364,7 +365,7 @@ public:
 			.set    ("web_server_passenger_version", PASSENGER_VERSION)
 			.set    ("integration_mode", getIntegrationModeString())
 			.set    ("passenger_root",  passengerRoot)
-			.setInt ("log_level",       getLogLevel());
+			.setInt ("log_level",       (int) LoggingKit::getLevel());
 		extraParams.addTo(params);
 
 		if (!params.getBool("user_switching", false, true)
@@ -456,8 +457,8 @@ public:
 
 			/****** Read agents information report ******/
 
-			this_thread::restore_interruption ri(di);
-			this_thread::restore_syscall_interruption rsi(dsi);
+			boost::this_thread::restore_interruption ri(di);
+			boost::this_thread::restore_syscall_interruption rsi(dsi);
 			UPDATE_TRACE_POINT();
 
 			try {
